@@ -70,3 +70,22 @@ def setModuleLocale(moduleName, newLocale=None):
     module = sys.modules.get(moduleName)
     if module:
         imp.reload(module)
+
+def setLocaleForMessages(newLocale=None):
+    modules = ['orca.tutorialgenerator', 'orca.messages']
+    for module in modules:
+        setModuleLocale(module, newLocale)
+
+def setLocaleForNames(newLocale=None):
+    modules = ['orca.chnames', 'orca.keynames', 'orca.phonnames',
+               'orca.text_attribute_names', 'orca.object_properties',
+               'orca.cmdnames', 'orca.keybindings']
+    for module in modules:
+        setModuleLocale(module, newLocale)
+
+def setLocaleForGUI(newLocale=None):
+    modules = ['orca.orca_gtkbuilder', 'orca.orca_gui_prefs',
+               'orca.app_gui_prefs', 'orca.guilabels',
+               'orca.brltablenames']
+    for module in modules:
+        setModuleLocale(module, newLocale)
